@@ -2,6 +2,7 @@
 
 #define ENDPOINT_H
 
+#include <cmath>
 #include <vector>
 
 #include <R.h>
@@ -36,6 +37,8 @@ public:
       exact equality is intended by the calling code. Given this assumption,
       there is no need for a relative difference approach here.
     */
+    if (std::isnan(other.pos)) return false;
+    if (std::isnan(this->pos)) return true;
     if ( this->pos == other.pos ) 
       return( this->state() < other.state() );
     else
